@@ -6,15 +6,16 @@
 
 #include "element.h"
 
-Element::Element(qreal p_x, qreal p_y, Maze *p_maze) : m_xInit(p_x), m_yInit(p_y),  m_maze(p_maze)
+Element::Element(qreal p_x, qreal p_y, Maze *p_maze)
+    : m_xInit(p_x)
+    , m_yInit(p_y)
+    , m_maze(p_maze)
 {
     m_points = 0;
     initCoordinate();
 }
 
-Element::~Element()
-{
-}
+Element::~Element() = default;
 
 void Element::doActionOnCollision(Kapman *)
 {
@@ -58,7 +59,7 @@ QString Element::getImageId() const
     return m_imageId;
 }
 
-void  Element::setImageId(const QString &p_imageId)
+void Element::setImageId(const QString &p_imageId)
 {
     m_imageId = p_imageId;
 }
@@ -68,3 +69,5 @@ void Element::initCoordinate()
     setX(m_xInit);
     setY(m_yInit);
 }
+
+#include "moc_element.cpp"
